@@ -1391,6 +1391,411 @@ class KrakenAPI(object):
 
         return trades, count
 
+    @crl_sleep
+    @callratelimiter('ledger/trade history')
+    def get_deposit_methods(self, asset='XBT', otp=None):
+        """Get methods available for depositing a particular asset.
+
+        Return a ``pd.DataFrame`` of deposit methods info.
+
+        Parameters
+        ----------
+        asset : str (default='XBT')
+            Asset for which to return deposit methods.
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        depositmethods : pd.DataFrame
+            Table containing trade balance info.
+            method = name of deposit method
+            limit = maximum net amount that can be deposited right now, or false if no limit
+            fee = amount of fees that will be paid
+            address-setup-fee = whether or not method has an address setup fee
+            gen-address = whether new addresses can be generated for this method
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('DepositMethods', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        depositmethods = pd.DataFrame(index=[asset], data=res['result']).T
+
+        return depositmethods
+
+    @crl_sleep
+    @callratelimiter('ledger/trade history')
+    def get_deposit_addresses(self, asset='XBT', method='Bitcoin', new=False, otp=None):
+        """Get (or generate a new) deposit addresses for a particular asset and method.
+
+        Return a ``pd.DataFrame`` of deposit methods info.
+
+        Parameters
+        ----------
+        asset : str (default='XBT')
+            Asset being deposited
+
+        method : str (default='Bitcoin')
+            Name of the deposit method
+
+        new : boolean, optional (default=False)
+            Whether or not to generate a new address
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        depositmethods : pd.DataFrame
+            Table containing trade balance info.
+            address = deposit Address
+            expiretm = expiration time in unix timestamp, or 0 if not expiring
+            new = whether or not address has ever been used
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('DepositAddresses', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        depositaddresses = pd.DataFrame(index=[asset], data=res['result']).T
+
+        return depositaddresses
+
+    @crl_sleep
+    @callratelimiter('ledger/trade history')
+    def get_deposit_status(self, asset='XBT', method=None, otp=None):
+        """Get information about recent deposits made.
+
+        Return a ``pd.DataFrame`` of recent deposits.
+
+        Parameters
+        ----------
+        asset : str (default='XBT')
+            Asset being deposited
+
+        method : str, optional (default=None)
+            Name of the deposit method
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        depositstatus : pd.DataFrame
+            Table containing recent deposit status info.
+            method = name of deposit method
+            aclass = asset class
+            asset = asset
+            refid = reference ID
+            txid = method transaction ID
+            info = method transaction information
+            amount = amount deposited
+            fee = fees paid
+            time = unix timestamp when request was made
+            status = status of deposit
+            status-prop = addition status properties (if available)
+                          "return": a return transaction initiated by Kraken
+                          "onhold": deposit is on hold pending review
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('DepositStatus', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        depositstatus = pd.DataFrame(index=[asset], data=res['result']).T
+
+        return depositstatus
+
+    @crl_sleep
+    @callratelimiter('other')
+    def get_withdrawal_information(self, key, asset='XBT', amount=0.0, otp=None):
+        """Retrieve fee information about potential withdrawals for a particular asset, key and amount.
+
+        Return a ``pd.DataFrame`` of withdrawal info.
+
+        Parameters
+        ----------
+        key : str
+            Withdrawal key name, as set up on your account.
+
+        asset : str (default='XBT')
+            Asset being withdrawn.
+
+        amount : float (default=0.0)
+            Amount to be withdrawn.
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required).
+
+        Returns
+        -------
+        withdrawal_info : pd.DataFrame
+            Table containing withdrawal info.
+            method = name of asset
+            limit = max. available for withdraw
+            amount = withdrawn amount (fees already subtracted)
+            fee = withdrawal fees
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items()
+                if arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('WithdrawInfo', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        withdrawal_info = pd.DataFrame(index=[asset], data=res['result']).T
+
+        return withdrawal_info
+
+    @crl_sleep
+    @callratelimiter('other')
+    def withdraw_funds(self, key, asset='XBT', amount=0.0, otp=None):
+        """Make a withdrawal request.
+
+        Initialize a withdrawal and return the withdrawal refid.
+
+        Parameters
+        ----------
+        key : str
+            Withdrawal key name, as set up on your account.
+
+        asset : str (default='XBT')
+            Asset being withdrawn.
+
+        amount : float (default=0.0)
+            Amount to be withdrawn.
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required).
+
+        Returns
+        -------
+        withdrawal_refid : str
+            refid of the withdraw request.
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items()
+                if arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Withdraw', data=data)
+
+        # check for error
+        if len(res["error"]) > 0:
+            raise KrakenAPIError(res['error'])
+
+        return res['result']
+
+    @crl_sleep
+    @callratelimiter('other')
+    def get_withdrawal_status(self, asset='XBT', method=None, otp=None):
+        """Retrieve information about recently requests withdrawals.
+
+        Return a ``pd.DataFrame`` of recent withdrawals.
+
+        Parameters
+        ----------
+        asset : str (default='XBT')
+            Asset being withdrawn.
+
+        method : str (default=None)
+            Name of the withdrawal method.
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required).
+
+        Returns
+        -------
+        withdrawalstatus : pd.DataFrame
+            Table containing recent withdrawal status info.
+            method = name of withdrawal method
+            aclass = asset class
+            asset = asset
+            refid = reference ID
+            txid = method transaction ID
+            info = method transaction information
+            amount = amount withdrawn
+            fee = fees paid
+            time = unix timestamp when request was made
+            status = status of withdrawal
+            status-prop = addition status properties (if available)
+                          "cancel-pending" cancelation requested
+                          "canceled" canceled
+                          "cancel-denied" cancelation requested but was denied
+                          "return" a return transaction initiated by Kraken; it cannot be canceled
+                          "onhold" withdrawal is on hold pending review
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items()
+                if arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('WithdrawStatus', data=data)
+
+        # check for error
+        if len(res["error"]) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        withdrawalstatus = pd.DataFrame(index=[asset], data=res['result']).T
+
+        return withdrawalstatus
+
+    @crl_sleep
+    @callratelimiter('other')
+    def cancel_withdrawal(self, asset='XBT', refid=None, otp=None):
+        """Cancel a recently requested withdrawal, if it has not already been successfully processed.
+
+        Returns whether cancellation was successful or not.
+
+        Parameters
+        ----------
+        asset : str (default='XBT')
+            Asset being withdrawn.
+
+        refid : str (default=None)
+            Withdrawal reference ID.
+
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required).
+
+        Returns
+        -------
+        succes : bool
+            Whether cancellation was successful or not.
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items()
+                if arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('WithdrawCancel', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        return res['result']
+
     @crl_sleep
     @callratelimiter('ledger/trade history')
     def query_trades_info(self, txid, trades=False, otp=None, ascending=False):
@@ -2086,3 +2491,277 @@ class KrakenAPI(object):
         if self.api_counter < 0:
             self.api_counter = 0
         self.time_of_last_query = now
+
+    def get_stakeable_assets(self, otp=None):
+        """Get list of stakeable assets and staking details.
+
+        Return a ``pd.DataFrame`` of asset that the user is able to stake.
+        This operation requires an API key with both `Withdraw funds` and
+        `Query funds` permission.
+
+        Parameters
+        ----------
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        assets : pd.DataFrame
+            Table containing asset names staking details.
+            index = asset name
+            method = Unique ID of the staking option (used in Stake/Unstake
+            operations)
+            staking_asset = Staking asset code/name
+            on_chain = Whether the staking operation is on-chain or not.
+            can_stake = Whether the user will be able to stake this asset.
+            can_unstake = Whether the user will be able to unstake this asset.
+            rewards.reward = Reward earned while staking.
+            rewards.type = Reward type.
+            minimum_amount.staking = minimum amount that can be staked.
+            minimum_amount.unstaking = minimum amount that can be unstaked
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Staking/Assets', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        assets = pd.json_normalize(data=res['result']).set_index('asset')
+
+        return assets
+
+    def get_pending_staking_transactions(self, otp=None):
+        """Get list of pending staking transactions.
+
+        Returns a ``pd.DataFrame`` of pending staking transactions.
+
+        Parameters
+        ----------
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        transactions : pd.DataFrame
+            Table containing transaction refids and details.
+            index = refid
+            type = Type of transaction {'bonding', 'reward', 'unbonding'}
+            asset = Asset code/name
+            amount = The transaction amount
+            time = Unix timestamp when the transaction was initiated.
+            bond_start = Unix timestamp from the start of bond period
+            (applicable only to `bonding` transactions).
+            bond_end = Unix timestamp of the end of bond period
+            (applicable only to `bonding` transactions).
+            status = Transaction status {'Initial', 'Pending', 'Settled'
+            'Success', 'Failure'}
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Staking/Pending', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        try:
+            transactions = pd.json_normalize(
+                data=res['result']
+            ).set_index('refid')
+        except KeyError:
+            return None
+
+        return transactions
+
+    def get_staking_transactions(self, otp=None):
+        """Returns the list of 1000 recent staking transactions from past
+        90 days.
+
+        Returns a ``pd.DataFrame`` of staking transactions.
+
+        Parameters
+        ----------
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        transactions : pd.DataFrame
+            Table containing transaction refids and details.
+            index = refid
+            type = Type of transaction {'bonding', 'reward', 'unbonding'}
+            asset = Asset code/name
+            amount = The transaction amount
+            time = Unix timestamp when the transaction was initiated.
+            bond_start = Unix timestamp from the start of bond period
+            (applicable only to `bonding` transactions).
+            bond_end = Unix timestamp of the end of bond period
+            (applicable only to `bonding` transactions).
+            status = Transaction status {'Initial', 'Pending', 'Settled'
+            'Success', 'Failure'}
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Staking/Transactions', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # create dataframe
+        try:
+            transactions = pd.json_normalize(
+                data=res['result']
+            ).set_index('refid')
+        except KeyError:
+            return None
+
+        return transactions
+
+    def stake_asset(self, asset, amount, method, otp=None):
+        """Stake an asset from your spot wallet. This operation requires an
+        API key with `Withdraw funds` permission.
+
+        Returns a ``str`` of the transaction Reference ID.
+
+        Parameters
+        ----------
+        asset : str
+            Asset to stake (asset ID or `altname`)
+        amount : float
+            Amount of the asset to stake
+        method : str
+            Name of the staking option to use (refer to the Staking Assets
+            endpoint for the correct method names for each asset)
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        refid : str
+            Transaction Reference ID
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Stake', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        return res['result']
+
+    def unstake_asset(self, asset, amount, otp=None):
+        """Unstake an asset from your staking wallet. This operation requires
+        an API key with `Withdraw funds` permission.
+
+        Returns a ``str`` of the transaction Reference ID.
+
+        Parameters
+        ----------
+        asset : str
+            Asset to unstake (asset ID or `altname`). Must be a valid staking
+            asset (e.g. XBT.M, XTZ.S, ADA.S)
+        amount : float
+            Amount of the asset to stake
+        otp : str
+            Two-factor password (if two-factor enabled, otherwise not required)
+
+        Returns
+        -------
+        refid : str
+            Transaction Reference ID
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # create data dictionary
+        data = {arg: value for arg, value in locals().items() if
+                arg != 'self' and value is not None}
+
+        # query
+        res = self.api.query_private('Unstake', data=data)
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        return res['result']
